# -*- coding: utf-8 -*-
import decimal
import re
import urllib.parse
from datetime import datetime, date


def url_parse(k):
    return urllib.parse.unquote(str(k))


def url_encode(k):
    return urllib.parse.quote(str(k))


# 给不能dump的字段，改为能dump
def parse_dict(item):
    for k in item:
        if isinstance(item[k], str):
            pass
        elif isinstance(item[k], dict):
            item[k] = parse_dict(item[k])
        elif isinstance(item[k], list):
            item[k] = parse_dict(item[k])
        elif isinstance(item[k], decimal.Decimal):
            item[k] = float(item[k])
        elif isinstance(item[k], datetime):
            item[k] = item[k].strftime('%Y-%m-%d %H:%M:%S')
        elif isinstance(item[k], date):
            item[k] = item[k].strftime('%Y-%m-%d')
    return item


# 从url中获取参数列表
def format_url_to_dict(url):
    res = {}
    try:
        values = url.split('?')[-1]
        if values:
            for key_value in values.split('&'):
                if key_value.find("=") >= 0:
                    try:
                        res[key_value.split('=')[0]] = key_value.split('=')[1]
                    except Exception as e:
                        print(e)
                        raise
    except Exception as e:
        print(e)
        raise
    return res


def delHtml(str1):
    str1 = str1.replace("<br />", "\n").replace("<br/>", "\n").replace("<br>", "\n").replace("<hr />", "\n")
    return re.compile(r"<[^>]+>", re.S).sub('', str(str1)) if str1 else ""


def decode_url(url):
    import urllib.parse
    return urllib.parse.unquote(url)


# 删除字符串
def delStr(from_str, start_str, end_str):
    s_index = from_str.find(start_str)
    if s_index > 0:
        s_index = len(start_str) + s_index
        e_index = from_str.find(end_str, s_index)
        if s_index < e_index:
            from_str1 = from_str[:s_index - 1]
            from_str2 = from_str[e_index + 1:]
            from_str = from_str1 + from_str2
            return cut_str(from_str, start_str, end_str)
        else:
            return from_str
    else:
        return from_str


# 切割字符串
def cut_str(from_str, start_str, end_str):
    s_index = from_str.find(start_str)
    if s_index > 0:
        s_index = len(start_str) + s_index
        e_index = from_str.find(end_str, s_index)
        if e_index >= s_index:
            return from_str[s_index:e_index]
        else:
            return from_str[s_index:]
    return ""


def get_cookies_from_list(l):
    # l = ['BDORZ=27315; max-age=86400; domain=.baidu.com; path=/','BDORZ2=27315; max-age=86400; domain=.baidu.com; path=/']
    cookies = {}
    for cookie in l:
        k_v = cookie.split(";")[0]
        k_v = k_v.split("=")
        cookies[k_v[0]] = k_v[1]
    return cookies


def get_cookie_from_str(cookie):
    lines = cookie.split(";")
    cookies = {}
    for line in lines:
        if line.find("=") >= 0:
            name, value = line.strip().split('=', 1)
            cookies[name] = value
    return cookies


def get_header_from_line_str(headers):
    return {each.split(':', 1)[0].strip(): each.split(':', 1)[1].strip() for each in headers.split('\n') if
            each.split()}


# 获取字符串中的数字
def get_num_from_str(msg):
    if isinstance(msg, str):
        return re.findall(r"\d+", str(msg))
    elif isinstance(msg, bytes):
        return re.findall(r"\d+", str(msg.decode("utf-8")))
    else:
        return msg


#  获取文本中的电话
def get_tel(text):
    tel = re.findall(r"\(?0\d{2,3}[) -]?\d{7,9}-\d{0,8}", text)
    if tel:
        return tel[0]
    else:
        tel = re.findall(r"1\d{10}$", text)
        if tel:
            return tel[0]
        return


def tff2_unicode():  # 将字体映射为unicode列表
    filename = '/home/jason/workspace/1.ttf'
    fnt = fontforge.open(filename)
    for i in fnt.glyphs():
        print(i.unicode)


if __name__ == '__main__':
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/14 16:18
# @Author   : Peter
# @Site       : 
# @File        : ForumReview_Count.py
# @Software: PyCharm
import scrapy


class PostReviewItem(scrapy.Item):
    id = scrapy.Field()
    forum_id = scrapy.Field()
    car_id = scrapy.Field()
    review_count = scrapy.Field()

    def __init__(self, *arg, **kw):
        super(PostReviewItem, self).__init__(self, *arg, **kw)
        self.id = None
        self.forum_id = ""
        self.car_id = ""
        self.review_count = ""



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/12/13 14:44
# @Email     : billsteve@126.com
# @Des       : 
# @File        : ComKeysModel
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, Integer
from sqlalchemy.dialects.mysql import VARCHAR
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class ComKey(Base, BaseModel):
    __tablename__ = 'com_keys'

    id = Column(Integer, primary_key=True)
    com_name = Column(VARCHAR(200))
    short_name = Column(VARCHAR(100))
    web_id = Column(Integer)
    web_url = Column(VARCHAR(100))
    web_key = Column(VARCHAR(100), unique=True)
    cassets = Column(Integer)
    cinvestment = Column(Integer)
    cjob = Column(Integer)
    clawsuit = Column(Integer)
    creport = Column(Integer)
    crun = Column(Integer)
    firm = Column(Integer)
    info = Column(VARCHAR(40))
    is_del = Column(Integer)
    level = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.cassets = kw.get("cassets", None)
        self.cinvestment = kw.get("cinvestment", None)
        self.cjob = kw.get("cjob", None)
        self.clawsuit = kw.get("clawsuit", None)
        self.com_name = kw.get("com_name", None)
        self.create_ts = kw.get("create_ts", None)
        self.creport = kw.get("creport", None)
        self.crun = kw.get("crun", None)
        self.firm = kw.get("firm", None)
        self.get = kw.get("get", None)
        self.getAll = kw.get("getAll", None)
        self.getAllIds = kw.get("getAllIds", None)
        self.getByFromId = kw.get("getByFromId", None)
        self.getByFromIdAndMod = kw.get("getByFromIdAndMod", None)
        self.getByName = kw.get("getByName", None)
        self.id = kw.get("id", None)
        self.info = kw.get("info", None)
        self.is_del = kw.get("is_del", None)
        self.level = kw.get("level", None)
        self.metadata = kw.get("metadata", None)
        self.short_name = kw.get("short_name", None)
        self.update_ts = kw.get("update_ts", None)
        self.web_key = kw.get("web_key", None)
        self.web_url = kw.get("web_url", None)
        self.web_id = kw.get("web_id", None)

    @staticmethod
    def saveComKey(data, session):
        web_key = data["web_key"]
        if web_key:
            exists = ComKey.getByKV("web_key", web_key, session)
            if not exists:
                web_key = ComKey(**data)
                ComKey.addModel(web_key, session)
                return web_key.id
            else:
                return exists[0].id



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/16 16:42
# @Author   : Peter
# @Des       : 
# @File        : User
# @Software: PyCharm
from sqlalchemy import Column, Integer, String, Text, Index
from sqlalchemy.ext.declarative import declarative_base

from XX.Model.SqlAlchemy.BaseModel import BaseModel

Base = declarative_base()
metadata = Base.metadata


class PostUserModel(Base, BaseModel):
    __tablename__ = 'bbs_post_user'
    __table_args__ = (
        Index('wy', 'forum_id', 'bbs_postor_web_id', unique=True),
    )

    id = Column(Integer, primary_key=True)
    forum_id = Column(Integer)
    bbs_postor_name = Column(String(60))
    bbs_postor_head_pic = Column(String(200))
    post_num = Column(Integer)
    regTime = Column(String(20))
    addr = Column(String(20))
    signature = Column(String(300))
    bbs_postor_web_id = Column(String(200))
    bbs_postor_homepage = Column(String(200))
    bbs_postor_info = Column(Text)
    is_vip = Column(Integer)
    is_locked = Column(Integer)
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.addr = kw.get("addr", None)
        self.bbs_postor_head_pic = kw.get("bbs_postor_head_pic", None)
        self.bbs_postor_homepage = kw.get("bbs_postor_homepage", None)
        self.bbs_postor_info = kw.get("bbs_postor_info", None)
        self.bbs_postor_name = kw.get("bbs_postor_name", None)
        self.bbs_postor_web_id = kw.get("bbs_postor_web_id", None)
        self.create_ts = kw.get("create_ts", None)
        self.forum_id = kw.get("forum_id", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.post_num = kw.get("post_num", None)
        self.regTime = kw.get("regTime", None)
        self.signature = kw.get("signature", None)
        self.update_ts = kw.get("update_ts", None)
        self.is_vip = kw.get("is_vip", None)
        self.is_locked = kw.get("is_locked", None)

    @staticmethod
    def getByForumIdAndPostorWebId(forum_id, bbs_postor_web_id, session):
        return session.query(PostUserModel).filter(PostUserModel.forum_id == forum_id, PostUserModel.bbs_postor_web_id == bbs_postor_web_id).all()


if __name__ == '__main__':
    import types

    print("""def __init__(self, *arg, **kw):""")
    for k in dir(PostUserModel):
        if not (str(k).startswith("_") or isinstance(getattr(PostUserModel, k), types.FunctionType)):
            print("""    self.{attr} = kw.get("{attr}", None)""".format(attr=k))



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2018/9/20 23:44
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : __init__.py
# @Software : PyCharm

if __name__ == '__main__':
    pass



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2018/12/23 16:38
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : CompanyEmployeeModel.py
# @Des         : 
# @Software : PyCharm
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, String
from sqlalchemy.dialects.mysql import INTEGER
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class CompanyEmployee(Base, BaseModel):
    __tablename__ = 'company_employee'

    id = Column(INTEGER(11), primary_key=True)
    com_id = Column(INTEGER(11))
    web_key = Column(String(255, 'utf8mb4_unicode_ci'))
    Name = Column(String(255, 'utf8mb4_unicode_ci'))
    person_id = Column(INTEGER(11))
    Job = Column(String(255, 'utf8mb4_unicode_ci'))
    CerNo = Column(String(255, 'utf8mb4_unicode_ci'))
    ScertName = Column(String(255, 'utf8mb4_unicode_ci'))
    is_del = Column(INTEGER(11))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.CerNo = kw.get("CerNo", None)
        self.Job = kw.get("Job", None)
        self.Name = kw.get("Name", None)
        self.ScertName = kw.get("ScertName", None)
        self.com_id = kw.get("com_id", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.person_id = kw.get("person_id", None)
        self.update_ts = kw.get("update_ts", None)
        self.web_key = kw.get("web_key", None)


if __name__ == '__main__':
    createInitFunction(CompanyEmployee)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/15 15:48
# @Author   : Peter
# @Site       : 
# @File        : __init__.py.py
# @Software: PyCharm


if __name__ == "__main__":
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time         : 2019/4/29 23:20
# @File           : ZhihuModel
# @Des           : 
# @Email        : billsteve@126.com
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, String, TIMESTAMP, text
from sqlalchemy.dialects.mysql import INTEGER, LONGTEXT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class Answer(Base, BaseModel):
    __tablename__ = 'answer'

    id = Column(INTEGER(11), primary_key=True)
    web_id = Column(String(255))
    type = Column(String(255))
    excerpt = Column(String(255))
    url = Column(String(255))
    voteupCount = Column(INTEGER(11))
    commentCount = Column(INTEGER(11))
    createdTime = Column(INTEGER(11))
    updatedTime = Column(INTEGER(11))
    content = Column(String(255))
    thumbnailInfo = Column(LONGTEXT)
    relationship = Column(LONGTEXT)
    question_web_id = Column(LONGTEXT)
    author_web_id = Column(LONGTEXT)
    flag = Column(String(255))
    attachedInfoBytes = Column(String(255))
    is_del = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))
    update_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.attachedInfoBytes = kw.get("attachedInfoBytes", None)
        self.author_web_id = kw.get("author_web_id", None)
        self.commentCount = kw.get("commentCount", None)
        self.content = kw.get("content", None)
        self.create_ts = kw.get("create_ts", None)
        self.createdTime = kw.get("createdTime", None)
        self.excerpt = kw.get("excerpt", None)
        self.flag = kw.get("flag", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.question_web_id = kw.get("question_web_id", None)
        self.relationship = kw.get("relationship", None)
        self.thumbnailInfo = kw.get("thumbnailInfo", None)
        self.type = kw.get("type", None)
        self.update_ts = kw.get("update_ts", None)
        self.updatedTime = kw.get("updatedTime", None)
        self.url = kw.get("url", None)
        self.voteupCount = kw.get("voteupCount", None)
        self.web_id = kw.get("web_id", None)


class Article(Base, BaseModel):
    __tablename__ = 'article'

    id = Column(INTEGER(11), primary_key=True)
    web_id = Column(String(255))
    title = Column(String(255))
    type = Column(String(255))
    url = Column(String(255))
    excerpt = Column(String(255))
    voteupCount = Column(INTEGER(11))
    commentCount = Column(INTEGER(11))
    createdTime = Column(INTEGER(11))
    updatedTime = Column(INTEGER(11))
    content = Column(String(255))
    thumbnailInfo = Column(LONGTEXT)
    author_web_id = Column(LONGTEXT)
    voting = Column(INTEGER(11))
    relationship = Column(LONGTEXT)
    flag = Column(String(255))
    attachedInfoBytes = Column(String(255))
    is_del = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))
    update_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.attachedInfoBytes = kw.get("attachedInfoBytes", None)
        self.author_web_id = kw.get("author_web_id", None)
        self.commentCount = kw.get("commentCount", None)
        self.content = kw.get("content", None)
        self.create_ts = kw.get("create_ts", None)
        self.createdTime = kw.get("createdTime", None)
        self.excerpt = kw.get("excerpt", None)
        self.flag = kw.get("flag", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.relationship = kw.get("relationship", None)
        self.thumbnailInfo = kw.get("thumbnailInfo", None)
        self.title = kw.get("title", None)
        self.type = kw.get("type", None)
        self.update_ts = kw.get("update_ts", None)
        self.updatedTime = kw.get("updatedTime", None)
        self.url = kw.get("url", None)
        self.voteupCount = kw.get("voteupCount", None)
        self.voting = kw.get("voting", None)
        self.web_id = kw.get("web_id", None)


class Topic(Base, BaseModel):
    __tablename__ = 'topic'

    id = Column(INTEGER(11), primary_key=True)
    unansweredCount = Column(INTEGER(11))
    bestAnswerersCount = Column(INTEGER(11))
    isBlack = Column(String(255))
    relationship = Column(LONGTEXT)
    isIndexVisible = Column(String(255))
    excerpt = Column(String(255))
    isVote = Column(String(255))
    isIndexEditable = Column(String(255))
    meta_web_id = Column(String(255))
    isFollowing = Column(String(255))
    web_id = Column(String(255))
    questionsCount = Column(INTEGER(11))
    category = Column(String(255))
    name = Column(String(255))
    introduction = Column(String(255))
    fatherCount = Column(INTEGER(11))
    headerCard = Column(LONGTEXT)
    url = Column(String(255))
    followersCount = Column(INTEGER(11))
    avatarUrl = Column(String(255))
    bestAnswersCount = Column(INTEGER(11))
    type = Column(String(255))
    is_del = Column(INTEGER(11), server_default=text("'0'"))
    create_ts = Column(INTEGER(11))
    update_ts = Column(TIMESTAMP, server_default=text("CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP"))

    def __init__(self, *arg, **kw):
        self.avatarUrl = kw.get("avatarUrl", None)
        self.bestAnswerersCount = kw.get("bestAnswerersCount", None)
        self.bestAnswersCount = kw.get("bestAnswersCount", None)
        self.category = kw.get("category", None)
        self.create_ts = kw.get("create_ts", None)
        self.excerpt = kw.get("excerpt", None)
        self.fatherCount = kw.get("fatherCount", None)
        self.followersCount = kw.get("followersCount", None)
        self.headerCard = kw.get("headerCard", None)
        self.id = kw.get("id", None)
        self.introduction = kw.get("introduction", None)
        self.isBlack = kw.get("isBlack", None)
        self.isFollowing = kw.get("isFollowing", None)
        self.isIndexEditable = kw.get("isIndexEditable", None)
        self.isIndexVisible = kw.get("isIndexVisible", None)
        self.isVote = kw.get("isVote", None)
        self.is_del = kw.get("is_del", None)
        self.meta_web_id = kw.get("meta_web_id", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.questionsCount = kw.get("questionsCount", None)
        self.relationship = kw.get("relationship", None)
        self.type = kw.get("type", None)
        self.unansweredCount = kw.get("unansweredCount", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)
        self.web_id = kw.get("web_id", None)


class User(Base, BaseModel):
    __tablename__ = 'users'

    id = Column(INTEGER(11), primary_key=True)
    avatarUrl = Column(String(255))
    badge = Column(LONGTEXT)
    gender = Column(INTEGER(11))
    headline = Column(String(255))
    web_id = Column(String(255))
    isFollowed = Column(String(255))
    isFollowing = Column(String(255))
    name = Column(String(255))
    type = Column(String(255))
    url = Column(String(255))
    urlToken = Column(String(255))
    userType = Column(String(255))
    is_del = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))
    update_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.avatarUrl = kw.get("avatarUrl", None)
        self.badge = kw.get("badge", None)
        self.create_ts = kw.get("create_ts", None)
        self.gender = kw.get("gender", None)
        self.headline = kw.get("headline", None)
        self.id = kw.get("id", None)
        self.isFollowed = kw.get("isFollowed", None)
        self.isFollowing = kw.get("isFollowing", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.type = kw.get("type", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)
        self.urlToken = kw.get("urlToken", None)
        self.userType = kw.get("userType", None)
        self.web_id = kw.get("web_id", None)


class WikiBox(Base, BaseModel):
    __tablename__ = 'wiki_box'

    id = Column(INTEGER(11), primary_key=True)
    web_id = Column(String(255))
    name = Column(String(255))
    url = Column(String(255))
    type = Column(String(255))
    excerpt = Column(String(255))
    introduction = Column(String(255))
    description = Column(String(255))
    avatarUrl = Column(String(255))
    isFollowing = Column(String(255))
    questionsCount = Column(INTEGER(11))
    followersCount = Column(INTEGER(11))
    followerCount = Column(INTEGER(11))
    topAnswerCount = Column(INTEGER(11))
    score = Column(INTEGER(11))
    aliases = Column(LONGTEXT)
    hasMeta = Column(String(255))
    meta_web_id = Column(LONGTEXT)
    attachedInfoBytes = Column(String(255))
    wikiType = Column(String(255))
    discussionCount = Column(INTEGER(11))
    hasIndexSection = Column(String(255))
    essenceFeedCount = Column(INTEGER(11))
    contentEssenceList = Column(LONGTEXT)
    extraContentEssenceList = Column(LONGTEXT)
    is_del = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))
    update_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.aliases = kw.get("aliases", None)
        self.attachedInfoBytes = kw.get("attachedInfoBytes", None)
        self.avatarUrl = kw.get("avatarUrl", None)
        self.contentEssenceList = kw.get("contentEssenceList", None)
        self.create_ts = kw.get("create_ts", None)
        self.description = kw.get("description", None)
        self.discussionCount = kw.get("discussionCount", None)
        self.essenceFeedCount = kw.get("essenceFeedCount", None)
        self.excerpt = kw.get("excerpt", None)
        self.extraContentEssenceList = kw.get("extraContentEssenceList", None)
        self.followerCount = kw.get("followerCount", None)
        self.followersCount = kw.get("followersCount", None)
        self.hasIndexSection = kw.get("hasIndexSection", None)
        self.hasMeta = kw.get("hasMeta", None)
        self.id = kw.get("id", None)
        self.introduction = kw.get("introduction", None)
        self.isFollowing = kw.get("isFollowing", None)
        self.is_del = kw.get("is_del", None)
        self.meta_web_id = kw.get("meta_web_id", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.questionsCount = kw.get("questionsCount", None)
        self.score = kw.get("score", None)
        self.topAnswerCount = kw.get("topAnswerCount", None)
        self.type = kw.get("type", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)
        self.web_id = kw.get("web_id", None)
        self.wikiType = kw.get("wikiType", None)


if __name__ == '__main__':
    createInitFunction(NewsSearch)



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2019/1/21 20:54
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : CheckDM.py
# @Des         : 
# @Software : PyCharm
import time
from XX.DB.RedisHelper import *
from logzero import logger
import XX.BuiltinFunctions as BF

HBASE_HTML_EXPIRE_TS = 86400 * 30


class Not200(object):

    @classmethod
    def from_crawler(cls, crawler):
        cls.settings = crawler.settings
        return cls()

    def __init__(self):
        self.conn_redis = RedisHelper.get_redis_connect(host=self.settings.get("REDIS_HOST"), password=self.settings.get("REDIS_PWD"), port=self.settings.get("REDIS_PORT"))

    def process_response(self, request, response, spider):
        if response.status != self.settings.get("STATUS_CODE", 200):
            logger.info("=== Add not 200 set res is \t" + str(self.conn_redis.sadd(spider.name + ":start_urls:not200", response.url)))

        # 延时
        err_count = self.conn_redis.scard(spider.name + ":start_urls:not200")
        for i in range(int(err_count)):
            BF.print_from_head("Has " + str(err_count) + " error url Please wait" + "." * i)
            time.sleep(1)
        return response



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/12/17 11:47
# @Email     : billsteve@126.com
# @Des       : 
# @File        : IPHelper
# @Software: PyCharm
import socket


def getUrlIpList(domain):  # 获取域名解析出的IP列表
    ip_list = []
    try:
        addr_info = socket.getaddrinfo(domain, None)
        for item in addr_info:
            if item[4][0] not in ip_list:
                ip_list.append(item[4][0])
    except Exception as e:
        pass
    return ip_list


if __name__ == '__main__':
    ips = getUrlIpList("www.zgjsks.com")
    print(ips)



# coding: utf-8
from sqlalchemy import Column, Index, String, TIMESTAMP, Table, Text, text
from sqlalchemy.dialects.mysql import BIGINT, INTEGER, LONGTEXT, TINYINT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class QqmusicAlbum(Base):
    __tablename__ = 'qqmusic_album'

    id = Column(String(128), primary_key=True, unique=True)
    epoch = Column(String(32))
    web_mid = Column(String(40), nullable=False)
    name = Column(String(200), server_default=text("''"))
    picture_url = Column(String(400), server_default=text("''"))
    pic_str = Column(String(200), server_default=text("''"))
    pic = Column(String(200))
    release_date = Column(String(20), server_default=text("''"))
    artist_web_ids = Column(String(200), server_default=text("''"))
    artist_names = Column(String(255))
    share_num = Column(BIGINT(40))
    comment_num = Column(BIGINT(40))
    play_num = Column(BIGINT(40))
    collect_num = Column(BIGINT(40))
    intro = Column(LONGTEXT)
    music_web_mids = Column(Text)
    status = Column(INTEGER(11))
    createtime = Column(TIMESTAMP, server_default=text("CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP"))


t_qqmusic_playinfo = Table(
    'qqmusic_playinfo', metadata,
    Column('id', String(32), nullable=False, index=True),
    Column('epoch', String(20)),
    Column('listenCount', BIGINT(40)),
    Column('topTitle', String(255), server_default=text("''")),
    Column('type', String(255)),
    Column('status', String(255)),
    Column('createtime', TIMESTAMP, server_default=text("CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP")),
    Index('web_id', 'id', 'epoch', unique=True)
)


class QqmusicPlaylist(Base):
    __tablename__ = 'qqmusic_playlist'

    id = Column(String(32), primary_key=True, index=True)
    songId = Column(BIGINT(22))
    name = Column(String(200), nullable=False)
    url = Column(String(400), nullable=False)
    web_mid = Column(String(60), index=True)
    artist_web_mids = Column(String(255))
    artist_web_ids = Column(String(255), nullable=False)
    artist_names = Column(String(255))
    album_web_id = Column(INTEGER(10), nullable=False)
    album_web_mid = Column(String(40), server_default=text("''"))
    term = Column(String(32), index=True, server_default=text("''"))
    epoch = Column(String(32))
    rank = Column(INTEGER(11), index=True)
    rankType = Column(INTEGER(11))
    rankValue = Column(String(255))
    recType = Column(INTEGER(11))
    vid = Column(String(255))
    is_only = Column(TINYINT(1), server_default=text("'0'"))
    pay_info = Column(Text)
    pay_month = Column(INTEGER(11))
    price_track = Column(INTEGER(11))
    price_album = Column(INTEGER(11))
    pay_play = Column(INTEGER(11))
    pay_down = Column(INTEGER(11))
    pay_status = Column(INTEGER(11))
    time_free = Column(INTEGER(11))
    status = Column(INTEGER(11), server_default=text("'0'"))
    createtime = Column(TIMESTAMP, nullable=False, server_default=text("CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP"))


class QqmusicRanklist(Base):
    __tablename__ = 'qqmusic_ranklist'

    id = Column(String(32), primary_key=True)
    name = Column(String(32))
    web_id = Column(String(32))
    epoch = Column(String(255))
    is_del = Column(TINYINT(1), server_default=text("'0'"))
    update_ts = Column(INTEGER(11))
    create_ts = Column(TIMESTAMP, server_default=text("CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP"))


class QqmusicSong(Base):
    __tablename__ = 'qqmusic_song'
    __table_args__ = (
        Index('i_', 'id', 'epoch'),
    )

    id = Column(String(64), primary_key=True, index=True)
    epoch = Column(String(32))
    web_id = Column(BIGINT(22))
    web_mid = Column(String(60))
    rank_list_id = Column(String(32))
    star = Column(BIGINT(20))
    bullet_num = Column(BIGINT(40))
    comment_num = Column(BIGINT(40), server_default=text("'0'"))
    status = Column(TINYINT(4))
    createtime = Column(TIMESTAMP, server_default=text("CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP"))


class Test(Base):
    __tablename__ = 'test'

    id = Column(INTEGER(11), primary_key=True)
    v1 = Column(String(255))
    v2 = Column(String(255))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/11/27 13:50
# @Author   : Bill
# @Email      : billsteve@126.com
# @Des       : 
# @File        : __init__.py
# @Software: PyCharm

if __name__ == "__main__":
    pass


# -*- coding: utf-8 -*-
import time
from threading import Thread


def thread_call(fn):
    def wrapper(*args, **kwargs):
        Thread(target=fn, args=args, kwargs=kwargs).start()

    return wrapper


class Test:
    def __index__(self):
        pass

    @staticmethod
    @thread_call
    def aa():
        print(int(time.time()))
        time.sleep(2)
        print(int(time.time()))
        return {"k", "v"}


if __name__ == '__main__':
    l = []
    for url in range(10):
        r = Test.aa()
        print(r)
    print(l)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/10/26 15:12
# @Author   : Peter
# @Des       : 
# @File        : InfoModel
# @Software: PyCharm
# coding: utf-8
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, Integer, Index, TEXT, VARCHAR, text
from sqlalchemy.dialects.mysql.types import TINYINT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class Info12315(Base, BaseModel):
    __tablename__ = 'info12315'
    __table_args__ = (
        Index('wy', 'NBXH', 'REGNO', unique=True),
        Index('REGNO', 'REGNO', 'NBXH')
    )

    id = Column(Integer, primary_key=True)
    ADDR = Column(VARCHAR(255))
    ANADDR = Column(VARCHAR(255))
    ENTTYPE = Column(VARCHAR(255))
    ENTTYPENAME = Column(VARCHAR(255))
    HIGHLIGHTTITLE = Column(VARCHAR(255))
    INVOPT = Column(VARCHAR(255))
    JYFW = Column(TEXT)
    NBXH = Column(VARCHAR(80))
    PRIPID = Column(VARCHAR(255))
    QYBM = Column(VARCHAR(255))
    QYWZ = Column(VARCHAR(255))
    REGNO = Column(VARCHAR(80))
    REGSTATECODE = Column(VARCHAR(255))
    REGSTATE_CN = Column(VARCHAR(255))
    REGUNIT = Column(VARCHAR(255))
    REGUNITNAME = Column(VARCHAR(255))
    SQ = Column(VARCHAR(255))
    S_EXT_NODENUM = Column(VARCHAR(255))
    TEL = Column(VARCHAR(255))
    UBINDTYPE = Column(VARCHAR(255))
    UBINDTYPENAME = Column(VARCHAR(255))
    UNITCODE = Column(VARCHAR(255))
    UNITNAME = Column(VARCHAR(255))
    XZQHBM = Column(VARCHAR(255))
    is_del = Column(Integer)
    u_ts = Column(Integer)
    c_ts = Column(Integer)
    crawl_detail = Column(TINYINT(4), server_default=text("'0'"))

    def __init__(self, *arg, **kw):
        self.ADDR = kw.get("ADDR", None)
        self.ANADDR = kw.get("ANADDR", None)
        self.ENTTYPE = kw.get("ENTTYPE", None)
        self.ENTTYPENAME = kw.get("ENTTYPENAME", None)
        self.HIGHLIGHTTITLE = kw.get("HIGHLIGHTTITLE", None)
        self.INVOPT = kw.get("INVOPT", None)
        self.JYFW = kw.get("JYFW", None)
        self.NBXH = kw.get("NBXH", None)
        self.PRIPID = kw.get("PRIPID", None)
        self.QYBM = kw.get("QYBM", None)
        self.QYWZ = kw.get("QYWZ", None)
        self.REGNO = kw.get("REGNO", None)
        self.REGSTATECODE = kw.get("REGSTATECODE", None)
        self.REGSTATE_CN = kw.get("REGSTATE_CN", None)
        self.REGUNIT = kw.get("REGUNIT", None)
        self.REGUNITNAME = kw.get("REGUNITNAME", None)
        self.SQ = kw.get("SQ", None)
        self.S_EXT_NODENUM = kw.get("S_EXT_NODENUM", None)
        self.TEL = kw.get("TEL", None)
        self.UBINDTYPE = kw.get("UBINDTYPE", None)
        self.UBINDTYPENAME = kw.get("UBINDTYPENAME", None)
        self.UNITCODE = kw.get("UNITCODE", None)
        self.UNITNAME = kw.get("UNITNAME", None)
        self.XZQHBM = kw.get("XZQHBM", None)
        self.c_ts = kw.get("c_ts", None)
        self.crawl_detail = kw.get("crawl_detail", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.u_ts = kw.get("u_ts", None)


if __name__ == '__main__':
    createInitFunction(Info12315)



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2019/1/7 0:05
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : ArticleContent.py
# @Des         : 
# @Software : PyCharm
import XX.Model.SqlAlchemy.BaseModel as BM
from sqlalchemy import CHAR, Column, Text
from sqlalchemy.dialects.mysql import INTEGER, TINYINT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class ArticleContentModel(Base, BM.BaseModel):
    __tablename__ = 'article_content'

    id = Column(INTEGER(11), primary_key=True)
    article_id = Column(INTEGER(11))
    content = Column(Text)
    hash_key = Column(CHAR(32))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.article_id = kw.get("article_id", None)
        self.content = kw.get("content", None)
        self.create_ts = kw.get("create_ts", None)
        self.hash_key = kw.get("hash_key", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)


if __name__ == '__main__':
    BM.createInitFunction(ArticleContentModel)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/8/16 16:33
# @Author   : Peter
# @Des       : 
# @File        : P{ost
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import BaseModel
from sqlalchemy import Column, Integer, String, Text
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class PostBaseModel(object):

    @classmethod
    def getBySpiderWebIdFloor(cls, spider, web_id, floor, session):
        return session.query(cls).filter(cls.spider == spider, cls.bbs_web_id == web_id, cls.bbs_floor == floor).all()


class PostModel(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post'

    id = Column(Integer, primary_key=True)
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(Integer)
    bbs_reply_floor = Column(Integer)
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_reply_floor = kw.get("bbs_reply_floor", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostsModel(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_posts'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel09(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_09'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel10(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_10'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel11(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_11'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel12(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_12'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel13(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_13'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel14(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_14'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel15(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_15'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel16(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_16'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel17(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_17'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel18(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_18'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)


class PostModel19(Base, BaseModel, PostBaseModel):
    __tablename__ = 'bbs_post_19'

    id = Column(Integer, primary_key=True)
    uuid = Column(String(35))
    spider = Column(String(100))
    bbs_forum = Column(String(100), nullable=False)
    bbs_catalog = Column(String(100))
    bbs_crawl_ts = Column(Integer)
    bbs_url = Column(String(200))
    bbs_source_url = Column(String(200))
    bbs_web_id = Column(Integer)
    bbs_title = Column(String(200))
    bbs_content = Column(Text)
    bbs_time = Column(Integer)
    bbs_floor = Column(Integer)
    bbs_url_kw = Column(Text)
    bbs_product_id = Column(Integer)
    bbs_forum_id = Column(Integer)
    bbs_info = Column(Text)
    bbs_reply_id = Column(String(65))
    bbs_postor_id = Column(Integer)
    has_pic = Column(Integer)
    bbs_type = Column(String(20))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.id = kw.get("id", None)
        self.uuid = kw.get("uuid", None)
        self.spider = kw.get("spider", None)
        self.bbs_forum = kw.get("bbs_forum", None)
        self.bbs_catalog = kw.get("bbs_catalog", None)
        self.bbs_crawl_ts = kw.get("bbs_crawl_ts", None)
        self.bbs_url = kw.get("bbs_url", None)
        self.bbs_source_url = kw.get("bbs_source_url", None)
        self.bbs_web_id = kw.get("bbs_web_id", None)
        self.bbs_title = kw.get("bbs_title", None)
        self.bbs_content = kw.get("bbs_content", None)
        self.bbs_time = kw.get("bbs_time", None)
        self.bbs_floor = kw.get("bbs_floor", None)
        self.bbs_url_kw = kw.get("bbs_url_kw", None)
        self.bbs_product_id = kw.get("bbs_product_id", None)
        self.bbs_forum_id = kw.get("bbs_forum_id", None)
        self.bbs_info = kw.get("bbs_info", None)
        self.bbs_reply_id = kw.get("bbs_reply_id", None)
        self.bbs_postor_id = kw.get("bbs_postor_id", None)
        self.has_pic = kw.get("has_pic", None)
        self.bbs_type = kw.get("bbs_type", None)
        self.is_del = kw.get("is_del", None)
        self.create_ts = kw.get("create_ts", None)
        self.update_ts = kw.get("update_ts", None)



# -*- coding:utf-8 -*-
# @Time       : 2019/4/30 9:58
from pip._internal.utils.misc import get_installed_distributions
from subprocess import call

for dist in get_installed_distributions():
    call("py -m pip install --upgrade " + dist.project_name + " -i https://pypi.douban.com/simple ", shell=True)



# -*- coding:utf-8 -*-
from sqlalchemy import Column, Integer, String, Index
from sqlalchemy.ext.declarative import declarative_base
from XX.Model.SqlAlchemy.BaseModel import BaseModel

Base = declarative_base()
metadata = Base.metadata


class ReadNum(Base, BaseModel):
    __tablename__ = 'read_num'
    __table_args__ = (
        Index('wy', 'UserId', 'Idx', unique=True),
    )

    id = Column(Integer, primary_key=True)
    UserId = Column(String(255))
    Idx = Column(Integer)
    ReadSumType = Column(Integer)
    ReadSumTypeDesc = Column(String(255))
    ArticleCount = Column(Integer)
    ReadNumMax = Column(Integer)
    ReadNumAvg = Column(Integer)
    LikeNumMax = Column(Integer)
    LikeNumAvg = Column(Integer)
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.ArticleCount = kw.get("ArticleCount", None)
        self.Idx = kw.get("Idx", None)
        self.LikeNumAvg = kw.get("LikeNumAvg", None)
        self.LikeNumMax = kw.get("LikeNumMax", None)
        self.ReadNumAvg = kw.get("ReadNumAvg", None)
        self.ReadNumMax = kw.get("ReadNumMax", None)
        self.ReadSumType = kw.get("ReadSumType", None)
        self.ReadSumTypeDesc = kw.get("ReadSumTypeDesc", None)
        self.UserId = kw.get("UserId", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)

    @staticmethod
    def getInfoByUserIdAndIdx(UserId, Idx, session):
        infos = session.query(ReadNum).filter(ReadNum.UserId == UserId, ReadNum.Idx == Idx).all()
        return infos[0].id if infos else None


if __name__ == '__main__':
    import types

    print("""\n\n\ndef __init__(self, *arg, **kw):""")
    for k in dir(ReadNum):
        if not (str(k).startswith("_") or isinstance(getattr(ReadNum, k), types.FunctionType)):
            print("""    self.{attr} = kw.get("{attr}", None)""".format(attr=k))



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2018/8/17 0:29
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : Company.py
# @Software : PyCharm
from sqlalchemy import Column, Integer, Index, String, Text, or_
from sqlalchemy.ext.declarative import declarative_base

from XX.Model.SqlAlchemy.BaseModel import *

Base = declarative_base()
metadata = Base.metadata


class CompanyModel(Base, BaseModel):
    __tablename__ = 'company'
    __table_args__ = (
        Index('wy', 'NBXH', 'REGNO', unique=True),
    )

    id = Column(Integer, primary_key=True)
    company_id = Column(Integer)
    ADDR = Column(String(255))
    ANADDR = Column(String(255))
    ENTTYPE = Column(String(255))
    ENTTYPENAME = Column(String(255))
    HIGHLIGHTTITLE = Column(String(255))
    INVOPT = Column(String(255))
    JYFW = Column(Text(collation='utf8mb4_unicode_ci'))
    NBXH = Column(String(80), index=True)
    PRIPID = Column(String(255))
    QYBM = Column(String(255))
    QYWZ = Column(String(255))
    REGNO = Column(String(80), index=True)
    REGSTATECODE = Column(String(255))
    REGSTATE_CN = Column(String(255))
    REGUNIT = Column(String(255))
    REGUNITNAME = Column(String(255))
    SQ = Column(String(255))
    S_EXT_NODENUM = Column(String(255))
    TEL = Column(String(255))
    UBINDTYPE = Column(String(255))
    UBINDTYPENAME = Column(String(255))
    UNITCODE = Column(String(255))
    UNITNAME = Column(String(255))
    XZQHBM = Column(String(255))
    reg_time = Column(Integer)
    is_del = Column(Integer)
    u_ts = Column(Integer)
    c_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.ADDR = kw.get("ADDR", None)
        self.ANADDR = kw.get("ANADDR", None)
        self.company_id = kw.get("company_id", None)
        self.ENTTYPE = kw.get("ENTTYPE", None)
        self.ENTTYPENAME = kw.get("ENTTYPENAME", None)
        self.HIGHLIGHTTITLE = kw.get("HIGHLIGHTTITLE", None)
        self.INVOPT = kw.get("INVOPT", None)
        self.JYFW = kw.get("JYFW", None)
        self.NBXH = kw.get("NBXH", None)
        self.PRIPID = kw.get("PRIPID", None)
        self.QYBM = kw.get("QYBM", None)
        self.QYWZ = kw.get("QYWZ", None)
        self.REGNO = kw.get("REGNO", None)
        self.REGSTATECODE = kw.get("REGSTATECODE", None)
        self.REGSTATE_CN = kw.get("REGSTATE_CN", None)
        self.REGUNIT = kw.get("REGUNIT", None)
        self.REGUNITNAME = kw.get("REGUNITNAME", None)
        self.SQ = kw.get("SQ", None)
        self.S_EXT_NODENUM = kw.get("S_EXT_NODENUM", None)
        self.TEL = kw.get("TEL", None)
        self.UBINDTYPE = kw.get("UBINDTYPE", None)
        self.UBINDTYPENAME = kw.get("UBINDTYPENAME", None)
        self.UNITCODE = kw.get("UNITCODE", None)
        self.UNITNAME = kw.get("UNITNAME", None)
        self.XZQHBM = kw.get("XZQHBM", None)
        self.c_ts = kw.get("c_ts", None)
        self.reg_time = kw.get("reg_time", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.u_ts = kw.get("u_ts", None)

    @staticmethod
    def getByINVOPT(name, session):
        return session.query(CompanyModel).filter(CompanyModel.INVOPT == name).limit(1).all()

    @staticmethod
    def getByRegnoOrNbxh(regno, nbxh, session):
        return session.query(CompanyModel).filter(or_(CompanyModel.REGNO == regno, CompanyModel.NBXH == nbxh)).limit(1).all()

    @staticmethod
    def getByRegno(regno, session):
        return session.query(CompanyModel).filter(CompanyModel.REGNO == regno).all()

    @staticmethod
    def getByNBXH(nbxh, session):
        return session.query(CompanyModel).filter(CompanyModel.NBXH == nbxh).all()


if __name__ == '__main__':
    createInitFunction(CompanyModel)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/10/12 11:22
# @Author   : Peter
# @Des       : 
# @File        : LogCrawled
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, Integer, String
from sqlalchemy.dialects.mysql.types import TINYINT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class LogCrawledModel(Base, BaseModel):
    __tablename__ = 'log_crawled'

    id = Column(Integer, primary_key=True)
    web_key = Column(String(40))
    spiders = Column(String(40))
    relation = Column(TINYINT(1))
    is_del = Column(TINYINT(1))
    c_ts = Column(Integer)
    u_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.c_ts = kw.get("c_ts", None)
        self.web_key = kw.get("web_key", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.relation = kw.get("relation", None)
        self.spiders = kw.get("spiders", None)
        self.u_ts = kw.get("u_ts", None)


if __name__ == '__main__':
    createInitFunction(LogCrawledModel)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/11/20 16:51
# @Author   : Peter
# @Des       : 
# @File        : WeiboInfo
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import BaseModel
from sqlalchemy import Column, String
from sqlalchemy.dialects.mysql import INTEGER
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class WeiboInfo(Base, BaseModel):
    __tablename__ = 'weibo_info'

    id = Column(INTEGER(11), primary_key=True)
    user_id = Column(INTEGER(11))
    created_at = Column(String(255))
    web_id = Column(String(255))
    idstr = Column(String(255))
    mid = Column(String(255))
    can_edit = Column(String(255))
    show_additional_indication = Column(INTEGER(11))
    text = Column(String(255))
    textLength = Column(INTEGER(11))
    source = Column(String(255))
    favorited = Column(String(255))
    thumbnail_pic = Column(String(255))
    bmiddle_pic = Column(String(255))
    original_pic = Column(String(255))
    is_paid = Column(String(255))
    mblog_vip_type = Column(INTEGER(11))
    reposts_count = Column(INTEGER(11))
    comments_count = Column(INTEGER(11))
    attitudes_count = Column(INTEGER(11))
    pending_approval_count = Column(INTEGER(11))
    isLongText = Column(String(255))
    reward_exhibition_type = Column(INTEGER(11))
    hide_flag = Column(INTEGER(11))
    expire_time = Column(INTEGER(11))
    mblogtype = Column(INTEGER(11))
    more_info_type = Column(INTEGER(11))
    cardid = Column(String(255))
    extern_safe = Column(INTEGER(11))
    content_auth = Column(INTEGER(11))
    hide_hot_flow = Column(INTEGER(11))
    mark = Column(String(255))
    weibo_position = Column(INTEGER(11))
    show_attitude_bar = Column(INTEGER(11))
    readtimetype = Column(String(255))
    bid = Column(String(255))
    is_del = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))
    update_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.attitudes_count = kw.get("attitudes_count", None)
        self.bid = kw.get("bid", None)
        self.bmiddle_pic = kw.get("bmiddle_pic", None)
        self.can_edit = kw.get("can_edit", None)
        self.cardid = kw.get("cardid", None)
        self.comments_count = kw.get("comments_count", None)
        self.content_auth = kw.get("content_auth", None)
        self.create_ts = kw.get("create_ts", None)
        self.created_at = kw.get("created_at", None)
        self.expire_time = kw.get("expire_time", None)
        self.extern_safe = kw.get("extern_safe", None)
        self.favorited = kw.get("favorited", None)
        self.hide_flag = kw.get("hide_flag", None)
        self.hide_hot_flow = kw.get("hide_hot_flow", None)
        self.id = kw.get("id", None)
        self.idstr = kw.get("idstr", None)
        self.isLongText = kw.get("isLongText", None)
        self.is_del = kw.get("is_del", None)
        self.is_paid = kw.get("is_paid", None)
        self.mark = kw.get("mark", None)
        self.mblog_vip_type = kw.get("mblog_vip_type", None)
        self.mblogtype = kw.get("mblogtype", None)
        self.metadata = kw.get("metadata", None)
        self.mid = kw.get("mid", None)
        self.more_info_type = kw.get("more_info_type", None)
        self.original_pic = kw.get("original_pic", None)
        self.pending_approval_count = kw.get("pending_approval_count", None)
        self.readtimetype = kw.get("readtimetype", None)
        self.reposts_count = kw.get("reposts_count", None)
        self.reward_exhibition_type = kw.get("reward_exhibition_type", None)
        self.show_additional_indication = kw.get("show_additional_indication", None)
        self.show_attitude_bar = kw.get("show_attitude_bar", None)
        self.source = kw.get("source", None)
        self.text = kw.get("text", None)
        self.textLength = kw.get("textLength", None)
        self.thumbnail_pic = kw.get("thumbnail_pic", None)
        self.update_ts = kw.get("update_ts", None)
        self.user_id = kw.get("user_id", None)
        self.web_id = kw.get("web_id", None)
        self.weibo_position = kw.get("weibo_position", None)


if __name__ == '__main__':
    import types

    print("""def __init__(self, *arg, **kw):""")
    for k in dir(WeiboInfo):
        if not (str(k).startswith("_") or isinstance(getattr(WeiboInfo, k), types.FunctionType)):
            print("""    self.{attr} = kw.get("{attr}", None)""".format(attr=k))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/11/27 13:50
# @Author   : Bill
# @Email      : billsteve@126.com
# @Des       : MySQL数据库连接配置对象
# @File        : Mysql
# @Software: PyCharm
import functools


def get_mysql_conn_cfg(**kw):
    d = dict()
    d["host"] = kw.get("host", "localhost")
    d["user"] = kw.get("user", "root")
    d["pwd"] = kw.get("pwd", "root")
    d["port"] = kw.get("port", 3306)
    d["charset"] = kw.get("charset", "utf-8")
    d["db"] = kw.get("db", "test")
    d["echo"] = kw.get("echo", False)
    return d


qq_cfg = functools.partial(get_mysql_conn_cfg, host="cd-cdb-f41yw26m.sql.tencentcdb.com", user="root", pwd="HBroot21", db="company", port=63626, echo=False, charset="utf-8")
ubuntu_cfg = functools.partial(get_mysql_conn_cfg, host="192.168.1.44", user="root", pwd="rebind1234", port=3306, db="car", echo=False, charset="utf-8")
baidu_mysql = functools.partial(get_mysql_conn_cfg, host="106.12.154.163", user="root", pwd="HBroot21", port=3306, db="tyc", echo=False, charset="utf-8")
local_mcf = functools.partial(get_mysql_conn_cfg, host="localhost", user="root", pwd="DRsXT5ZJ6Oi55LPQ", port=3306, db="net_scan", echo=False, charset="utf-8")
ali_cfg_tmp = functools.partial(get_mysql_conn_cfg, host="rm-8vbzabox9s9kvomq61o.mysql.zhangbei.rds.aliyuncs.com", user="root", pwd="HBroot21", port=3306, db="data_sheet", echo=False, charset="utf-8")
ali_zhihan_cfg = functools.partial(get_mysql_conn_cfg, host="39.104.97.69", user="root", pwd="rebind1234", port=3366, db="data_sheet", echo=False, charset="utf-8")



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2018/8/25 2:42
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : ComBasic1.py
# @Software : PyCharm
import time

from XX.Model.SqlAlchemy.BaseModel import BaseModel
from sqlalchemy import Column, Integer, String, or_
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class ComBasic1Model(Base, BaseModel):
    __tablename__ = 'com_basic1'

    id = Column(Integer, primary_key=True)
    web_id = Column(String(255), unique=True)
    batchid = Column(String(255))
    oaddress = Column(String(255))
    orpt_name = Column(String(255))
    oname = Column(String(255))
    regcode = Column(String(255), index=True)
    uccode = Column(String(255), index=True)
    etcode = Column(String(255))
    max_score = Column(String(255))
    is_del = Column(Integer)
    c_ts = Column(Integer)
    u_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.batchid = kw.get("batchid", None)
        self.c_ts = kw.get("c_ts", None)
        self.etcode = kw.get("etcode", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.max_score = kw.get("max_score", None)
        self.metadata = kw.get("metadata", None)
        self.oaddress = kw.get("oaddress", None)
        self.oname = kw.get("oname", None)
        self.orpt_name = kw.get("orpt_name", None)
        self.regcode = kw.get("regcode", None)
        self.u_ts = kw.get("u_ts", None)
        self.uccode = kw.get("uccode", None)
        self.web_id = kw.get("web_id", None)


if __name__ == '__main__':
    import types

    print("""def __init__(self, *arg, **kw):""")
    for k in dir(ComBasic1Model):
        if not (str(k).startswith("_") or isinstance(getattr(ComBasic1Model, k), types.FunctionType)):
            print("""    self.{attr} = kw.get("{attr}", None)""".format(attr=k))



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2018/12/2 15:24
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : Json2File.py
# @Des         : 
# @Software : PyCharm
import os
import XX.Date.DatetimeHelper as dt
import XX.File.FileHelper as uf
import json


def JsonCheckDecorator(func):
    def inner(*args, **kwargs):
        if kwargs.get("json_data") or args[0]:
            func(*args, **kwargs)
        else:
            print("No Json 2 DB " + "===" * 30)

    return inner


# json数据保存到对应文件夹
def Json2File(fp=None, *dargs, **dkargs):
    def dec_func(func):
        def inner(*args, **kwargs):
            if len(args) < 2:
                json_data = kwargs.get("json_data", None)
                spider = kwargs.get("spider", None)
                fp = kwargs.get("fp", None)
            else:
                json_data = args[0]
                spider = args[1]
                fp = args[3]
            if json_data:
                today = dt.get_today().replace("-", "_")
                uf.FileHelper.mkdir(fp + spider)
                json.dump(json_data, open(fp + spider + os.sep + today + ".json", "a", encoding="utf-8"), ensure_ascii=False)
            return func(*args, **kwargs)  # 2

        return inner

    return dec_func


@JsonCheckDecorator
def test(json_data, mysql_cfg):
    print("Ok" * 22)
    pass



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2018/10/21 12:41
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : CompanyTyc.py
# @Software : PyCharm
# coding: utf-8
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, Integer, Index, String
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class CompanyTyc(Base, BaseModel):
    __tablename__ = 'company_tyc'
    __table_args__ = (
        Index('wy', 'no', 'creditno', unique=True),
    )

    id = Column(Integer, primary_key=True)
    web_id = Column(String(80, 'utf8mb4_unicode_ci'), index=True)
    name = Column(String(255, 'utf8mb4_unicode_ci'))
    no = Column(String(80, 'utf8mb4_unicode_ci'), index=True)
    creditno = Column(String(80, 'utf8mb4_unicode_ci'), index=True)
    is_del = Column(Integer)
    u_ts = Column(Integer)
    c_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.c_ts = kw.get("c_ts", None)
        self.creditno = kw.get("creditno", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.no = kw.get("no", None)
        self.u_ts = kw.get("u_ts", None)
        self.web_id = kw.get("web_id", None)


if __name__ == '__main__':
    createInitFunction(CompanyTyc)



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2019/1/6 13:30
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : ExtractNewsContent.py
# @Des         : 
# @Software : PyCharm
from newspaper import Article


class ExtractNewsContent:

    def __init__(self, *args, **kwargs):
        self.article = Article(kwargs.get("url", ""), keep_article_html=True, language=kwargs.get("language", "zh"))
        if kwargs.get("input_html"):
            self.article.download(input_html=kwargs.get("input_html"))
        self.article.parse()



# -*- encoding:utf8 -*-
import os
import shutil
import time

import XX.Encrypt.EncryptHelper as cenc


def addLineN(key): return key + "\n" if key else key


# 文件帮助类
class FileHelper(object):

    # 为行添加换行符
    def __init__(self, arg=""):
        super(FileHelper, self).__init__()
        self.arg = arg

    @staticmethod
    def get_file_list(file_path, *arg, **kw):
        for parent, dir_names, file_names in os.walk(file_path):
            dir_names.sort()
            for filename in file_names:
                yield parent, filename

    @staticmethod
    def get_file_size(fp, *args, **kw):
        return os.path.getsize(fp)

    @staticmethod
    def read_file_content(file_path, *arg, **kw):
        try:
            return open(file_path, "r", encoding="utf-8").read()
        except TypeError:
            return open(file_path, "r").read()
        except:
            raise

    @staticmethod
    def read_file_lines(file_path, *arg, **kw):
        try:
            return open(file_path, kw.get("method", "r"),
                        encoding=kw.get("encoding", "utf-8")).readlines()
        except TypeError:
            return open(file_path, "r").readline()
        except:
            raise

    @staticmethod
    def save_file(file_path, content="", method="a", *arg, **kw):
        try:
            FileHelper.mkdir(FileHelper.get_file_path_and_name(file_path)[0])
            return open(file_path, method, encoding=kw.get("encoding", "utf-8")).write(content)
        except TypeError:
            open(file_path, method).write(content)
            return len(content)
        except:
            raise

    @staticmethod
    def remove_dir(file_path):
        if not file_path:
            return
        file_path = file_path.strip()
        file_path = file_path.rstrip("\\")
        file_path = file_path.rstrip("/")
        isExists = os.path.exists(file_path)
        if isExists:
            shutil.rmtree(file_path)
        return True

    @staticmethod
    def mkdir(file_path):
        if not file_path:
            return
        file_path = file_path.strip()
        file_path = file_path.rstrip("\\")
        file_path = file_path.rstrip("/")
        exists = os.path.exists(file_path)
        if not exists:
            os.makedirs(file_path)
        return True

    @staticmethod
    def get_file_path_and_name(filename):
        if not filename:
            return None, None
        return os.path.split(filename)

    @staticmethod
    def get_file_ext(filename):
        return os.path.splitext(filename)

    @staticmethod
    def rename_file(filename, to_filename):
        return os.rename(filename, to_filename)

    @staticmethod
    def is_file_exit(path):
        return 1 if path and os.path.isfile(path) else 0

    @staticmethod
    def remove_file(path, ts=0):
        if ts and FileHelper.is_file_exit(path) and time.time() - os.path.getmtime(path) > ts:
            if FileHelper.is_file_exit(path):
                if int(time.time()) - FileHelper.get_create_ts(path) > ts:
                    os.remove(path)
                return not FileHelper.is_file_exit(path)
            else:
                return 1
        elif FileHelper.is_file_exit(path):
            os.remove(path)
            return not FileHelper.is_file_exit(path)
        else:
            return 1

    @staticmethod
    def move_file(ffrom, fto):
        FileHelper.mkdir(FileHelper.get_file_path_and_name(fto)[0])
        if not FileHelper.is_file_exit(fto):
            return shutil.move(ffrom, fto)
        else:
            return -1

    @staticmethod
    # c\4\c\c4ca4238a0b923820dcc509a6f75849b
    def get_md5_name(hash_string):
        md5_str = cenc.Encrypt.md5(hash_string)
        return md5_str[0] + os.sep + md5_str[1] + os.sep + md5_str[2] + os.sep + md5_str

    @staticmethod
    def copy(file_from, file_to):
        FileHelper.mkdir(FileHelper.get_file_path_and_name(file_to)[0])
        return shutil.copy(file_from, file_to)

    @staticmethod
    def mk16dir(root_path):
        words = ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "a", "b", "c", "d", "e", "f"]
        len_file = len(words)
        for i in range(len_file):
            for j in range(len_file):
                for k in range(len_file):
                    FileHelper.mkdir(
                        root_path + str(words[i]) + os.sep + str(words[j]) + os.sep + str(words[k]) + os.sep)
                    print(root_path + str(words[i]) + os.sep + str(words[j]) + os.sep + str(words[k]) + os.sep)

    # 获取文件创建时间
    @staticmethod
    def get_create_ts(fp):
        return os.path.getctime(fp)

    # 获取更新时间
    @staticmethod
    def get_update_ts(fp):
        return os.path.getmtime(fp)

    # 添加PYTHON环境变量
    @staticmethod
    def add_python_path(path):
        import sys
        sys.path.append(os.path.abspath(os.path.join(os.getcwd(), path)))

    # 修改后缀名
    @staticmethod
    def modify_suffix(fp, suffix):
        if FileHelper.is_file_exit(fp):
            portion = os.path.splitext(fp)
            new_name = portion[0] + "." + str(suffix)
            os.rename(fp, new_name)
        else:
            raise FileNotFoundError


if __name__ == "__main__":
    pass
    # print(FileHelper.getFileName("E:\\t82.html"))
    # print(FileHelper.getFileExt("E:\\t82.html"))

    # FileHelper.saveFile("E:\\ele\\ele\\111.log", "12121")
    # print(FileHelper.getMd5Name("1"))

    r = FileHelper.remove_file("C:\\Users\\billsteve\\Desktop\\tmp\\1.log")
    print(r)
    # print(FileHelper.getUpdateTs("d:\\1.html"))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# 放到Kakfa队列
import json

import XX.HTML.HtmlHelper as chtml
import XX.BuiltinFunctions as bf
from pykafka import KafkaClient


class KafkaPipeline(object):
    def __init__(self):

        self.client = KafkaClient(hosts="LOCALHOST" + ":6667")

    def process_item(self, item, spider):
        topic = self.client.topics[spider.name]
        producer = topic.get_producer()
        # 数据处理
        item = chtml.parse_dict(item)
        json_str = json.dumps(item, ensure_ascii=False)
        producer.produce(json_str)
        bf.print_from_head(spider.name + "\tAdd kafka")
        return item



# -*- coding: utf-8 -*-
import base64
import hashlib


class Encrypt:
    @staticmethod
    def md5(string):
        return hashlib.new("md5", string.encode("utf-8")).hexdigest()


def base64_encode(s):
    base64.b64encode(str(s).encode('utf-8'))


def base64_decode(s):
    base64.b64decode(s).decode("utf-8")


if __name__ == '__main__':
    print(Encrypt.md5("1"))



# -*- coding:utf-8 -*-
# 2018/12/2 16:26
import importlib
import json
import time

import XX.DB.SqlAlchemyHelper as sa
import XX.DB.RedisHelper as udr
import XX.Tools.BuiltinFunctions as bf
import XX.Threading.AsyncHelper as ah


class IDataCustomer:

    def customer(self, **kw):
        pass


class MQ2DB(IDataCustomer):

    def customer(self, **kw):
        pass

    @staticmethod
    def redis2mysql(*arg, **kw):
        pass

    @staticmethod
    def save2db(json_data, spider, mysql_cfg):
        module = importlib.import_module("SpiderJson2DB")
        func = getattr(module, spider)
        if func:
            return func(json_data, mysql_cfg, spider)
        else:
            print("No " + str(spider) + "'s  save 2 db")


class Redis2Mysql(MQ2DB):

    # 初始化redis和MySQL连接类
    def __init__(self, **kw):
        self.conn_redis = udr.RedisHelper.get_redis_connect_by_cfg(kw.get("redis_cfg"))
        self.conn_mysql = sa.SqlAlchemyHelper.get_session_by_cfg(kw.get("mysql_cfg"))

    # def customer(self, **kw):
    #     self.redis2mysql(**kw)

    # TODO:
    @ah.async_call
    def redis2mysql(self, **kw):
        while 1:
            spider = kw.get("spider")
            json_str = self.conn_redis.lpop(spider + ":items")
            if kw.get("debug"):
                # 放回
                self.conn_redis.lpush(spider + ":items", json_str)
            if json_str:
                json_data = json.loads(json_str, encoding="utf-8")
                func = kw.get("func")
                # func(json_data, kw.get("mysql_cfg"))
                func(json_data, self.conn_mysql)
            else:
                bf.print_no_end(spider + "\tNo more item")
                time.sleep(kw.get("ts", 5))
                if kw.get("once"):
                    print("One circle over")
                    break


#
def redis2mysql(**kw):
    conn_redis = udr.RedisHelper.get_redis_connect_by_cfg(kw.get("redis_cfg"))
    conn_mysql = sa.SqlAlchemyHelper.get_session_by_cfg(kw.get("mysql_cfg"))
    while 1:
        spider = kw.get("spider")
        json_str = conn_redis.rpop(spider + ":items")
        if kw.get("debug"):
            # 放回
            print("+++>>> Readd=====")
            conn_redis.lpush(spider + ":items", json_str)
        if json_str:
            json_data = json.loads(json_str, encoding="utf-8")
            func = kw.get("func")
            func(json_data, conn_mysql)
            conn_mysql.commit()
        else:
            # bf.printFromHead(spider + "\tNo more item")
            bf.print_from_head(spider + "\tNo more item \t")
            time.sleep(kw.get("ts", 5))
            if kw.get("once"):
                print("One circle over")
                break



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time         : 2019/1/25 17:56
# @File           : UserMoreModel
# @Des           : 
# @Email        : billsteve@126.com
import XX.Model.SqlAlchemy.BaseModel as BM
from sqlalchemy import Column, Float, String, Text
from sqlalchemy.dialects.mysql import BIGINT, INTEGER, TINYINT, VARCHAR
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class UserMore(Base, BM.BaseModel):
    __tablename__ = 'user_more'

    id = Column(INTEGER(11), primary_key=True)
    uid = Column(INTEGER(11), unique=True)
    user_web_id = Column(INTEGER(11))
    wb_comment_avg = Column(Float(11, True))
    wb_like_avg = Column(Float(11, True))
    wb_share_avg = Column(Float(11, True))
    wb_count_avg_per_month = Column(Float(11, True))
    car_offical = Column(TINYINT(1))
    types = Column(String(255))
    actionlog_ext = Column(String(255))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.actionlog_ext = kw.get("actionlog_ext", None)
        self.car_offical = kw.get("car_offical", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.types = kw.get("types", None)
        self.uid = kw.get("uid", None)
        self.user_web_id = kw.get("user_web_id", None)
        self.update_ts = kw.get("update_ts", None)
        self.wb_comment_avg = kw.get("wb_comment_avg", None)
        self.wb_count_avg_per_month = kw.get("wb_count_avg_per_month", None)
        self.wb_like_avg = kw.get("wb_like_avg", None)
        self.wb_share_avg = kw.get("wb_share_avg", None)

    @staticmethod
    def setAbout(uid, session):
        import time
        exists = UserMore.getIdByKV("uid", uid, session)
        if exists:
            res = UserMore.updateKV(uid, "car_offical", 1, session)
        else:
            ts = int(time.time())
            umm = UserMore(car_offical=1, uid=uid, create_ts=ts)
            UserMore.addModel(umm, session)
            res = id
        return res


if __name__ == '__main__':
    BM.createInitFunction(UserMore)



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2019/2/19 21:13
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : RR.py
# @Des         : 
# @Software : PyCharm
# 异常捕获装饰器（亦可用于类方法）
import functools
import time
import traceback

from pymysql.connections import Connection
from sqlalchemy.orm.session import Session


def try_except_log(f=None, max_retries: int = 2, delay: (int, float) = 0, step: (int, float) = 0,
                   exceptions: (BaseException, tuple, list) = BaseException, sleep=time.sleep,
                   process=None, validate=None, callback=None, default=None):
    """
    函数执行出现异常时自动重试的简单装饰器
    :param f: function 执行的函数。
    :param max_retries: int 最多重试次数。
    :param delay: int/float 每次重试的延迟，单位秒。
    :param step: int/float 每次重试后延迟递增，单位秒。
    :param exceptions: BaseException/tuple/list 触发重试的异常类型，单个异常直接传入异常类型，多个异常以tuple或list传入。
    :param sleep: 实现延迟的方法，默认为time.sleep。
    在一些异步框架，如tornado中，使用time.sleep会导致阻塞，可以传入自定义的方法来实现延迟。
    自定义方法函数签名应与time.sleep相同，接收一个参数，为延迟执行的时间。
    :param process: 处理函数，函数签名应接收一个参数，每次出现异常时，会将异常对象传入。
    可用于记录异常日志，中断重试等。
    如处理函数正常执行，并返回True，则表示告知重试装饰器异常已经处理，重试装饰器终止重试，并且不会抛出任何异常。
    如处理函数正常执行，没有返回值或返回除True以外的结果，则继续重试。
    如处理函数抛出异常，则终止重试，并将处理函数的异常抛出。
    :param validate: 验证函数，用于验证执行结果，并确认是否继续重试。
    函数签名应接收一个参数，每次被装饰的函数完成且未抛出任何异常时，调用验证函数，将执行的结果传入。
    如验证函数正常执行，且返回False，则继续重试，即使被装饰的函数完成且未抛出任何异常。
    如验证函数正常执行，没有返回值或返回除False以外的结果，则终止重试，并将函数执行结果返回。
    如验证函数抛出异常，且异常属于被重试装饰器捕获的类型，则继续重试。
    如验证函数抛出异常，且异常不属于被重试装饰器捕获的类型，则将验证函数的异常抛出。
    :param callback: 回调函数，函数签名应接收一个参数，异常无法处理时，会将异常对象传入。
    可用于记录异常日志，发送异常日志等。
    :param default: 默认值/默认值生成函数
    :return: 被装饰函数的执行结果。
    """

    # 带参数的装饰器
    def decorator(func):
        @functools.wraps(func)
        def wrapper(*args, **kwargs):
            # nonlocal delay, step, max_retries
            i = 0
            func_exc, exc_traceback = None, None
            while i < max_retries:
                try:
                    result = func(*args, **kwargs)
                    # 验证函数返回False时，表示告知装饰器验证不通过，继续重试
                    if callable(validate) and validate(result) is False:
                        continue
                    else:
                        return result
                except exceptions as ex:
                    func_exc, exc_traceback = ex, traceback.format_exc()
                    # 处理函数返回True时，表示告知装饰器异常已经处理，终止重试
                    if callable(process):
                        try:
                            if process(ex) is True:
                                return default() if callable(default) else default
                        except Exception as e:
                            func_exc, exc_traceback = e, traceback.format_exc()
                            break
                finally:
                    i += 1
                    sleep(delay + step * i)
            else:
                # 回调函数，处理自动无法处理的异常
                if callable(callback):
                    callback(exc_traceback, func_exc)
                    for k, v in kwargs.items():
                        if isinstance(v, (Session, Connection)):
                            v.rollback()
                    for i in args:
                        if isinstance(i, (Session, Connection)):
                            i.rollback()
                return default() if callable(default) else default
        return wrapper

    if callable(f):
        return decorator(f)
    return decorator


if __name__ == '__main__':
    @try_except_log
    def div():
        return 1 / 0


    print(div())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time         : 2019/1/30 14:53
# @File           : CacheHelper
# @Des           : 
# @Email        : billsteve@126.com
import os
import pickle

import XX.Encrypt.EncryptHelper as Enc
import XX.File.FileHelper as FH
import XX.BuiltinFunctions as BF
import XX.configs as cc
import happybase
from logzero import logger


# TODO:Rebuild(太不耦合)
def cache_file_2_hbase(root_path, hb_cfg, table_name, pro_num=0):
    conn_hbase = happybase.Connection(**hb_cfg)
    table = conn_hbase.table("crawl_" + table_name)
    for fp, fn in FH.FileHelper.get_file_list(root_path):
        # TODO：WORDS16改为string模式
        if not fn.startswith(cc.WORDS16[pro_num]):
            continue
        spider = fp.split(os.sep)[-4]
        response = pickle.load(open(fp + os.sep + fn, "rb"))
        row = spider + "_" + Enc.Encrypt.md5(response.url)
        if table.row(row):
            BF.print_from_head("Exists\t" + row)
            continue
        data = {
            "source:url": str(response.url),
            "source:status_code": str(response.status),
            "source:html": str(response.text),
            "source:type": "html",
            "source:size": str(len(response.text)),
            "source:encoding": response.encoding
        }
        table.put(row, data)
        logger.info(row)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/12/17 10:47
# @Email     : billsteve@126.com
# @Des       : 
# @File        : __init__.py
# @Software: PyCharm

if __name__ == "__main__":
    pass


# -*- coding: utf-8 -*-


def get_mongo_conn_cfg(**kw):
    d = dict()
    d["host"] = kw.get("host", "localhost")
    # d["username"] = kw.get("username", None)
    # d["password"] = kw.get("pwd", None)
    d["port"] = kw.get("port", 27017)
    return d

# ubuntu_cfg = get_mongo_conn_cfg(host="192.168.1.44")
# zhihan00_cfg = get_mongo_conn_cfg(host="192.168.1.50")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import base64
import random

from logzero import logger
from scrapy.downloadermiddlewares.httpproxy import HttpProxyMiddleware
from w3lib.http import basic_auth_header

import XX.DB.RedisHelper as Rh


# redisIP池代理
class IPPollingProxy:
    # ping from all province, then get cdn ip
    proxy_cdn = []

    # crawl everyday, then check them
    proxy_public = []

    # You must be allowed within the range of IP
    proxy_private = [
        'proxy.scrapy.com:23088',
    ]

    # all proxy pool
    proxy = proxy_public + proxy_private

    def process_request(self, request, spider):
        proxy_ip = random.choice(self.proxy)
        if proxy_ip:
            request.meta['proxy'] = "http://" + proxy_ip
        return


# 阿布云代理
class AbuyunProxy:

    @classmethod
    def from_crawler(cls, crawler):
        cls.settings = crawler.settings
        return cls()

    def process_request(self, request, spider):
        # 代理服务器
        proxy_url = "http://http-dyn.abuyun.com:9020"
        code = bytes((self.settings.get("PROXY_UN") + ":" + self.settings.get("PROXY_PWD")), "ascii")
        proxyAuth = "Basic " + base64.urlsafe_b64encode(code).decode("utf8")
        request.meta["proxy"] = proxy_url
        request.headers["Proxy-Authorization"] = proxyAuth


# 固定IP代理
class IpProxy:

    def __init__(self):
        # 获取Redis连接
        pass

    def process_request(self, request, spider):
        #  这是ip用例，如果想要实时更新，就可以从DB中获取
        ips = ["49.85.6.229:39896", "49.85.6.229:39896", "49.85.6.229:39896"]
        ip = random.choice(ips)
        request.meta["proxy"] = ip


# Goubanjia代理
class GoubanjiaProxy:

    def __init__(self):
        # 获取Redis连接
        pass

    def process_request(self, request, spider):
        #  这是ip用例，如果想要实时更新，就可以从DB中获取
        ips = ["49.85.6.229:39896"]
        ip = random.choice(ips)
        request.meta["proxy"] = ip


class MimvpProxy:

    @classmethod
    def from_crawler(cls, crawler):
        cls.settings = crawler.settings
        return cls()

    def __init__(self):
        self.conn_redis = Rh.RedisHelper.get_redis_connect(self.settings.get("REDIS_HOST"),
                                                           password=self.settings.get("REDIS_PWD"), db=9)

    def process_request(self, request, spider):
        ips = self.conn_redis.keys()
        if ips:
            request.meta["proxy"] = "http://c1259e45c76b:b7b9bd6b48@" + random.choice(ips)
            logger.info("Proxy is " + str(request.meta["proxy"]))
        else:
            logger.info("No Proxy ip")


# 快代理
class KuaiProxy:

    @classmethod
    def from_crawler(cls, crawler):
        cls.settings = crawler.settings
        return cls()

    def process_request(self, request, spider):
        request.meta['proxy'] = "http://%(proxy)s" % {'proxy': self.settings.get("PROXY_URL")}
        # 用户名密码认证 # 白名单认证可注释下一行
        request.headers['Proxy-Authorization'] = basic_auth_header(self.settings.get("PROXY_UN"), self.settings.get("PROXY_PWD"))
        # 这里是为了强制切换IP，因为隧道模式的IP有可能还能用
        request.headers["Connection"] = "close"
        return None


class Data5U(HttpProxyMiddleware):

    # 初始化
    def __init__(self, ip=''):
        super().__init__()
        self.ip = ip

    # 请求处理
    def process_request(self, request, spider):
        # 先随机选择一个IP
        IPPOOL = []
        thisip = random.choice(IPPOOL)
        print("当前使用IP是：" + thisip)
        request.meta["proxy"] = "http://" + thisip


class ProxyMiddleware:
    # scrapy暂不推荐使用，暂不提供技术支持

    # 代理服务器

    # appkey为你订单的key

    def process_request(self, request, spider):
        proxyServer = "transfer.moguproxy.com:9001"
        proxyAuth = "Basic " + ""
        request.meta["proxy"] = proxyServer

        request.headers["Authorization"] = proxyAuth



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time         : 2019/2/20 15:14
# @File           : DataSheet
# @Des           : 
# @Email        : billsteve@126.com
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, String, Text
from sqlalchemy.dialects.mysql import INTEGER, TINYINT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class Key(Base, BaseModel):
    __tablename__ = 'keys'

    id = Column(INTEGER(11), primary_key=True)
    k1 = Column(String(20))
    k2 = Column(String(100))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.k1 = kw.get("k1", None)
        self.k2 = kw.get("k2", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)


class Info(Base, BaseModel):
    __tablename__ = 'info'

    id = Column(INTEGER(11), primary_key=True)
    k_id = Column(INTEGER(11))
    k1 = Column(INTEGER(11))
    v1 = Column(INTEGER(11))
    PartNo = Column(String(100))
    Brand = Column(String(100))
    CategoryName = Column(String(100))
    DataParam = Column(Text)
    Description = Column(String(255))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.Brand = kw.get("Brand", None)
        self.CategoryName = kw.get("CategoryName", None)
        self.DataParam = kw.get("DataParam", None)
        self.Description = kw.get("Description", None)
        self.k_id = kw.get("k_id", None)
        self.k1 = kw.get("k1", None)
        self.v1 = kw.get("v1", None)
        self.PartNo = kw.get("PartNo", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)


class Snapshot(Base, BaseModel):
    __tablename__ = 'snapshot'

    id = Column(INTEGER(11), primary_key=True)
    kid = Column(INTEGER(11), index=True)
    source_url = Column(String(190), index=True)
    baidu_url = Column(String(190))
    title = Column(String(190), index=True)
    snapshot_url = Column(String(2000))
    crawl_ts = Column(INTEGER(11))
    is_del = Column(TINYINT(1))
    update_ts = Column(INTEGER(11))
    create_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.baidu_url = kw.get("baidu_url", None)
        self.crawl_ts = kw.get("crawl_ts", None)
        self.create_ts = kw.get("create_ts", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.kid = kw.get("kid", None)
        self.metadata = kw.get("metadata", None)
        self.snapshot_url = kw.get("snapshot_url", None)
        self.source_url = kw.get("source_url", None)
        self.title = kw.get("title", None)
        self.update_ts = kw.get("update_ts", None)


if __name__ == '__main__':
    createInitFunction(Snapshot)



# coding: utf-8
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, String, Text
from sqlalchemy.dialects.mysql import INTEGER, TINYINT
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class GpInfo(Base, BaseModel):
    __tablename__ = 'gp_info'

    id = Column(INTEGER(11), primary_key=True)
    url = Column(String(255, 'utf8mb4_unicode_ci'))
    encrypt_url = Column(String(255, 'utf8mb4_unicode_ci'))
    title = Column(String(255, 'utf8mb4_unicode_ci'))
    source_url = Column(String(255, 'utf8mb4_unicode_ci'))
    html = Column(Text(collation='utf8mb4_unicode_ci'))
    context = Column(Text(collation='utf8mb4_unicode_ci'))
    is_del = Column(TINYINT(1))
    create_ts = Column(INTEGER(11))
    update_ts = Column(INTEGER(11))

    def __init__(self, *arg, **kw):
        self.html = kw.get("html", None)
        self.context = kw.get("context", None)
        self.create_ts = kw.get("create_ts", None)
        self.encrypt_url = kw.get("encrypt_url", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.source_url = kw.get("source_url", None)
        self.title = kw.get("title", None)
        self.update_ts = kw.get("update_ts", None)
        self.url = kw.get("url", None)


if __name__ == '__main__':
    createInitFunction(GpInfo)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/9/25 14:29
# @Author   : Peter
# @Des       : 
# @File        : CompanyBasicModel
# @Software: PyCharm
# coding: utf-8
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, Integer, Index, VARCHAR, or_
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class CompanyBasicModel(Base, BaseModel):
    __tablename__ = 'company_basic'
    __table_args__ = (
        Index('wy', 'no', 'creditno', unique=True),
    )

    id = Column(Integer, primary_key=True)
    name = Column(VARCHAR(255))
    no = Column(VARCHAR(80), index=True)
    web_key = Column(VARCHAR(80), index=True)
    creditno = Column(VARCHAR(80), index=True)
    is_del = Column(Integer)
    u_ts = Column(Integer)
    c_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.c_ts = kw.get("c_ts", None)
        self.creditno = kw.get("creditno", None)
        self.get = kw.get("get", None)
        self.getAll = kw.get("getAll", None)
        self.getAllIds = kw.get("getAllIds", None)
        self.getByFromId = kw.get("getByFromId", None)
        self.getByFromIdAndMod = kw.get("getByFromIdAndMod", None)
        self.getByName = kw.get("getByName", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.metadata = kw.get("metadata", None)
        self.name = kw.get("name", None)
        self.web_key = kw.get("web_key", None)
        self.no = kw.get("no", None)
        self.u_ts = kw.get("u_ts", None)

    @staticmethod
    def getByNoOrCreditNo(no="", creditno="", session=None):
        return session.query(CompanyBasicModel).filter(or_(CompanyBasicModel.no == no, CompanyBasicModel.creditno == creditno)).limit(1).all()

    @staticmethod
    def updateComKey(id_, web_key, session):
        infos = session.query(CompanyBasicModel).filter(CompanyBasicModel.id == id_).update({CompanyBasicModel.web_key: web_key})
        session.commit()
        return infos

    @staticmethod
    def addBasic(data, session):
        if data.get("no"):
            exists = CompanyBasicModel.getByNo(data.get("no"), session)
        elif data.get("web_key"):
            exists = CompanyBasicModel.getByCreditNo(data.get("web_key"), session)
        elif data.get("creditno"):
            exists = CompanyBasicModel.getByCreditNo(data.get("creditno"), session)
        elif data.get("name"):
            exists = CompanyBasicModel.getByName(data.get("name"), session)
        else:
            return None
        if not exists:
            basic = CompanyBasicModel(**data)
            CompanyBasicModel.addModel(basic, session)
            return basic.id
        return exists[0].id


class TestModel(Base, BaseModel):
    __tablename__ = 'test'

    id = Column(Integer, primary_key=True)
    name = Column(VARCHAR(255))


if __name__ == '__main__':
    createInitFunction(TestModel)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/11/1 11:35
# @Author   : Peter
# @Des       : 
# @File        : UserInfo
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import BaseModel
from sqlalchemy import BigInteger, Column, Integer, String
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class UserInfo(Base, BaseModel):
    __tablename__ = 'user_info'

    id = Column(Integer, primary_key=True)
    web_id = Column(BigInteger, unique=True)
    fans_scheme = Column(String(255))
    follow_scheme = Column(String(255))
    showAppTips = Column(Integer)
    scheme = Column(String(255))
    screen_name = Column(String(255), index=True)
    profile_image_url = Column(String(255))
    profile_url = Column(String(255))
    statuses_count = Column(Integer)
    verified = Column(String(255))
    verified_type = Column(Integer)
    verified_type_ext = Column(Integer)
    verified_reason = Column(String(255))
    close_blue_v = Column(String(255))
    description = Column(String(255))
    gender = Column(String(255))
    mbtype = Column(Integer)
    urank = Column(Integer)
    mbrank = Column(Integer)
    follow_me = Column(String(255))
    following = Column(String(255))
    followers_count = Column(Integer)
    follow_count = Column(Integer)
    cover_image_phone = Column(String(255))
    avatar_hd = Column(String(255))
    like = Column(String(255))
    like_me = Column(String(255))
    containid = Column(String(30))
    home_page_containid = Column(String(30))
    is_del = Column(Integer)
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.avatar_hd = kw.get("avatar_hd", None)
        self.close_blue_v = kw.get("close_blue_v", None)
        self.containid = kw.get("containid", None)
        self.cover_image_phone = kw.get("cover_image_phone", None)
        self.create_ts = kw.get("create_ts", None)
        self.description = kw.get("description", None)
        self.fans_scheme = kw.get("fans_scheme", None)
        self.follow_count = kw.get("follow_count", None)
        self.follow_me = kw.get("follow_me", None)
        self.follow_scheme = kw.get("follow_scheme", None)
        self.followers_count = kw.get("followers_count", None)
        self.following = kw.get("following", None)
        self.gender = kw.get("gender", None)
        self.home_page_containid = kw.get("home_page_containid", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.like = kw.get("like", None)
        self.like_me = kw.get("like_me", None)
        self.mbrank = kw.get("mbrank", None)
        self.mbtype = kw.get("mbtype", None)
        self.metadata = kw.get("metadata", None)
        self.profile_image_url = kw.get("profile_image_url", None)
        self.profile_url = kw.get("profile_url", None)
        self.scheme = kw.get("scheme", None)
        self.screen_name = kw.get("screen_name", None)
        self.showAppTips = kw.get("showAppTips", None)
        self.statuses_count = kw.get("statuses_count", None)
        self.update_ts = kw.get("update_ts", None)
        self.urank = kw.get("urank", None)
        self.verified = kw.get("verified", None)
        self.verified_reason = kw.get("verified_reason", None)
        self.verified_type = kw.get("verified_type", None)
        self.verified_type_ext = kw.get("verified_type_ext", None)
        self.web_id = kw.get("web_id", None)


if __name__ == '__main__':
    import types

    print("""def __init__(self, *arg, **kw):""")
    for k in dir(UserInfo):
        if not (str(k).startswith("_") or isinstance(getattr(UserInfo, k), types.FunctionType)):
            print("""    self.{attr} = kw.get("{attr}", None)""".format(attr=k))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time         : 2019/1/17 11:09
# @File           : Mysql2Redis
# @Des           :
# @Email        : billsteve@126.com
import pymysql

from XX.List.ListHelper import ListHelper


class MysqlHelper:
    pool = None
    db = None
    host = None

    def __init__(self, host="127.0.0.1", user="root", password="root", db="test", port=3306, charset="utf8", **kw):
        self._conn = pymysql.connect(host=host, user=user, password=password, db=db, port=port, charset=charset.replace("-", ""))
        if kw.get("kv"):
            self.cur = self._conn.cursor(cursor=pymysql.cursors.DictCursor)
        else:
            self.cur = self._conn.cursor()

    def query(self, sql, values=None, cursor=None):
        self.cur.execute(sql, values)
        res = ListHelper.decode_v(self.cur.fetchall())
        return res

    def execute(self, sql, vals=None, cursor=None, commit=True):
        res = self.cur.execute(sql, vals)
        if commit:
            self._conn.commit()
        return res

    def commit(self):
        self._conn.commit()

    def rollback(self):
        self._conn.rollback()

    def lastrowid(self):
        return self.cur.lastrowid

    def close(self):
        self._conn.close()

    def dispose(self, method="commit"):
        if method == "commit":
            self._conn.commit()
        else:
            self._conn.rollback()
        self.cur.close()
        self._conn.close()


class SqlHelper:

    # 根据字段和ddl语句查看哪个字段没有
    @staticmethod
    def get_less_columns(jd, ddl):
        t = set()
        for line in ddl.split("\n"):
            if line and line.find("`") >= 0:
                t.add(line.split("`")[1])
        return set(jd.keys()) - t

    # 根据ddl获取所有字段
    @staticmethod
    def get_columns_list(ddl):
        t = []
        for line in ddl.split("\n"):
            if line and line.find("`") >= 0:
                t.append(line.split("`")[1])
        return t

    # 根据字典获取建表语句
    @staticmethod
    def get_table_sql_by_dict(d, tb_name="tb_name", tb_comment="COMMENT"):
        s = "\n\nCREATE TABLE `{tb_name}` (\n`id` int(11) NOT NULL AUTO_INCREMENT,\n\n".format(tb_name=tb_name)
        for k, v in d.items():
            if type(v) in [int, float]:
                s += """\t`{key}` int(11) DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
            elif type(v) == list:
                s += """\t`{key}` longtext DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
            elif type(v) == dict:
                if v.get("id"):
                    s += """\t`{key}_web_id`  varchar(255) DEFAULT NULL,""".format(key=k) + "\n"
                    print(":WebWebWebWebWeb")
                else:
                    s += """\t`{key}` longtext DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
            else:
                s += """\t`{key}` varchar(255) DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
        s += """
            `is_del` int(11) DEFAULT 0,
            `update_ts` int(11) DEFAULT NULL,
            `create_ts` timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`)
            ) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='{tb_comment}';""".format(tb_comment=tb_comment)
        print(s)

    # 根据dump文件获取所有表建表语句
    @staticmethod
    def get_tables_sql_by_sql_dump(fp):
        for line in open(fp, "r", encoding="utf-8"):
            if line.find("INSERT") >= 0 or line.find("--") >= 0 or line.find("/*") >= 0:
                continue
            print(line.strip())

    # 根据json生成sql
    @staticmethod
    def get_sql_by_dict(d, tb_name="tb_name", tb_comment="COMMENT"):
        s = "\n\nCREATE TABLE `{tb_name}` (\n`id` int(11) NOT NULL AUTO_INCREMENT,\n\n".format(tb_name=tb_name)
        for k, v in d.items():
            if type(v) in [int, float]:
                s += """\t`{key}` int(11) DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
            elif type(v) == list:
                s += """\t`{key}` longtext DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
            elif type(v) == dict:
                if v.get("id"):
                    s += """\t`{key}_web_id`  varchar(255) DEFAULT NULL,""".format(key=k) + "\n"
                    print(":WebWebWebWebWeb")
                else:
                    s += """\t`{key}` longtext DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
            else:
                s += """\t`{key}` varchar(255) DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
        s += """
            `is_del` int(11) DEFAULT 0,
            `update_ts` int(11) DEFAULT NULL,
            `create_ts` timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`)
            ) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='{tb_comment}';""".format(tb_comment=tb_comment)
        print(s)

    @staticmethod
    def get_create_table_sql_by_sql_dump(fp):
        for line in open(fp, "r", encoding="utf-8"):
            if line.find("INSERT") >= 0 or line.find("--") >= 0 or line.find("/*") >= 0:
                continue
            print(line.strip())


class DDLHelper:
    # 根据json生成sql
    @staticmethod
    def get_sql_by_dict(d, tb_name="tb_name", tb_comment="COMMENT"):
        s = "\n\nCREATE TABLE `{tb_name}` (\n`id` int(11) NOT NULL AUTO_INCREMENT,\n\n".format(tb_name=tb_name)
        for k, v in d.items():
            if type(v) in [int, float]:
                s += """\t`{key}` int(11) DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
            elif type(v) == list:
                s += """\t`{key}` longtext DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
            elif type(v) == dict:
                if v.get("id"):
                    s += """\t`{key}_web_id`  varchar(255) DEFAULT NULL,""".format(key=k) + "\n"
                    print(":WebWebWebWebWeb")
                else:
                    s += """\t`{key}` longtext DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
            else:
                s += """\t`{key}` varchar(255) DEFAULT NULL,""".format(key=k if str(k) != "id" else "web_id") + "\n"
        s += """
            `is_del` int(11) DEFAULT 0,
            `update_ts` int(11) DEFAULT NULL,
            `create_ts` timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (`id`)
            ) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='{tb_comment}';""".format(tb_comment=tb_comment)
        print(s)

    @staticmethod
    def get_create_table_sql_by_sql_dump(fp):
        for line in open(fp, "r", encoding="utf-8"):
            if line.find("INSERT") >= 0 or line.find("--") >= 0 or line.find("/*") >= 0:
                continue
            print(line.strip())

    @staticmethod
    def del_redis_keys_by_prefix(prefix, conn):
        for key in conn.keys():
            if str(key).startswith(prefix):
                conn.delete(key)
                print(key)



#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2018/12/2 16:10
import json
import time

import XX.DB.RedisHelper as dr
import XX.Date.DatetimeHelper as dt
import XX.Encrypt.EncryptHelper as enc
import XX.File.FileHelper as uf
import XX.Tools.BuiltinFunctions as bf
from logzero import logger
from thrift.transport import TSocket

try:
    from hbase import Hbase
    from hbase.ttypes import *
except ImportError as e:
    pass


class DataProducer:
    @staticmethod
    def json_2_redis(*args, **kw):
        pass

    @staticmethod
    def json_2_kafka(*args, **kw):
        pass


class JsonFileProducer(DataProducer):
    @staticmethod
    def json_2_redis(*args, **kw):
        redis_cfg = kw.get("redis_cfg")
        if not redis_cfg:
            print("No redis_cfg" + "===" * 10)
            return
        rename = kw.get("rename", 0)
        conn_redis = dr.RedisHelper.get_redis_connect_by_cfg(redis_cfg)
        fp = kw.get("fp", "")
        ts = kw.get("ts", 1)
        spider = kw.get("spider")
        if rename and str(fp).startswith(dt.get_today().replace("-", "_")):
            return

        for line in open(fp, encoding="utf-8"):
            length = conn_redis.llen(spider + ":items")
            if length > 50000:
                bf.print_from_head(fp + "\t Too much,Please customer\t" + str(length) + "\t\t")
                time.sleep(ts)
            bf.print_blank_end(conn_redis.lpush(spider + ":items", line))
        if rename:
            uf.FileHelper.rename_file(fp, str(fp) + "1")
        print("=====File Over\t" + fp + "=====")
        conn_redis.connection_pool.disconnect()


class JsonFile2HBase(JsonFileProducer):

    def __init__(self, *args, **kwargs):
        transport = TSocket.TSocket(kwargs.get("hbase_host", "localhost"), kwargs.get("hbase_port", 9090))
        transport.open()
        self.protocol = TBinaryProtocol.TBinaryProtocol(transport)
        self.client = Hbase.Client(self.protocol)

        # 判断是否有表，没有则生成
        tables = self.client.getTableNames()
        self.table_name = "crawl_" + kwargs.get("project", "test")
        if self.table_name not in tables:
            source = ColumnDescriptor(name='source')
            data = ColumnDescriptor(name='data')
            self.client.createTable(self.table_name, [source, data])

    def json_2_hbase(self, *args, **kwargs):
        fp = kwargs.get("fp", "")
        if fp:
            for line in open(fp, encoding="utf-8"):
                url = json.loads(line).get("url")
                if url:
                    row = kwargs.get("spider") + "_" + enc.Encrypt.md5(url)
                    mutations = list()
                    mutations.append(Mutation(column="data:json", value=str(line)))
                    self.client.mutateRow(self.table_name, row, mutations)
                    logger.info("Json  2 hbase " + row)
                else:
                    print("No url")
        else:
            print("No fp")


def json_file_line_2_redis(fp, spider, redis_cfg, fn, rename=1, ts=10):
    JsonFileProducer.json_2_redis(fp, spider, redis_cfg, fn, rename=1, ts=10)

# TODO:再抽象一层，就是把某个文件夹下的所有json添加到对应的文件夹队列中
# def run(process_num=10, rp):
# pass



# -*- encoding:utf8 -*-
import redis


class RedisHelper(object):
    pool = None
    host = None
    db = 0

    @staticmethod
    def get_redis_connect(host="127.0.0.1", port=6379, db=0, password=None, decode_responses=True):
        if RedisHelper.pool and RedisHelper.db == db and RedisHelper.host == host:
            return redis.Redis(connection_pool=RedisHelper.pool, decode_responses=decode_responses)
        else:
            RedisHelper.db = db
            RedisHelper.pool = redis.ConnectionPool(host=host, port=port, db=db, password=password, decode_responses=decode_responses)
            return redis.Redis(connection_pool=RedisHelper.pool, decode_responses=decode_responses)

    @staticmethod
    def get_redis_instance(host="127.0.0.1", port=6379, db=0, decode_responses=True):
        return redis.Redis(host=host, db=db, port=port, decode_responses=decode_responses)

    @staticmethod
    def get_redis_connect_by_cfg(cfg):
        return RedisHelper.get_redis_connect(**cfg)



# # -*- encoding:utf8 -*-

# 代理数量
PROXY_NUM = 5
# 是否是测试环境
TEST = 0
MASTER = 1
# 代理超限的时候 单进程暂停时间
TS_429 = 1

# 代理信息
PROXY_UN = "HF60345RM388C8ZD"
PROXY_PWD = "F583670DE9072F1E"

# 核对爬虫天数
CHECK_DAYS = 10

HEADERS = {
    "Accept": "application/json, text/javascript, */*; q=0.01",
    "Accept-Encoding": "gzip, deflate",
    "Accept-Language": "zh-CN,zh;q=0.5",
    "Cache-Control": "max-age=0",
    "Connection": "keep-alive",
    "Upgrade-Insecure-Requests": "1",
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/68.0.3440.106 Safari/537.36",
}


#!/usr/bin/python3
# -*- coding:utf-8 -*-
# @Time       : 2018/8/19 17:12
# @Author    : Bill Steve
# @Email      : billsteve@126.com
# @File         : Decorator.py
# @Software : PyCharm

if __name__ == '__main__':
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2018/9/19 18:00
# @Author   : Peter
# @Des       : 
# @File        : EleModel
# @Software: PyCharm
from XX.Model.SqlAlchemy.BaseModel import *
from sqlalchemy import Column, Integer
from sqlalchemy.dialects.mysql import TEXT, TINYINT, VARCHAR
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class ComInfo(Base, BaseModel):
    __tablename__ = 'com_info'

    id = Column(Integer, primary_key=True)
    OPSCOPE = Column(TEXT)
    entid = Column(VARCHAR(32), unique=True)
    DOM = Column(VARCHAR(255))
    ENTTYPE = Column(Integer)
    ESDATE = Column(VARCHAR(60))
    EMPNUM = Column(VARCHAR(60))
    logo = Column(VARCHAR(255))
    ENTSTATUS = Column(TINYINT(4))
    ENTNAME = Column(VARCHAR(255))
    DOMDISTRICT = Column(VARCHAR(20))
    fstatus = Column(TINYINT(4))
    faren = Column(VARCHAR(255))
    INDUSTRYCO = Column(VARCHAR(40))
    REGCAP = Column(VARCHAR(40))
    isent = Column(VARCHAR(40))
    is_del = Column(TINYINT(4))
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.DOM = kw.get("DOM", None)
        self.DOMDISTRICT = kw.get("DOMDISTRICT", None)
        self.EMPNUM = kw.get("EMPNUM", None)
        self.ENTNAME = kw.get("ENTNAME", None)
        self.ENTSTATUS = kw.get("ENTSTATUS", None)
        self.ENTTYPE = kw.get("ENTTYPE", None)
        self.ESDATE = kw.get("ESDATE", None)
        self.INDUSTRYCO = kw.get("INDUSTRYCO", None)
        self.OPSCOPE = kw.get("OPSCOPE", None)
        self.REGCAP = kw.get("REGCAP", None)
        self.create_ts = kw.get("create_ts", None)
        self.entid = kw.get("entid", None)
        self.faren = kw.get("faren", None)
        self.fstatus = kw.get("fstatus", None)
        self.getByFromId = kw.get("getByFromId", None)
        self.getByFromIdAndMod = kw.get("getByFromIdAndMod", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.isent = kw.get("isent", None)
        self.logo = kw.get("logo", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)


class ComInfoLes(Base, BaseModel):
    __tablename__ = 'com_info_less'

    id = Column(Integer, primary_key=True)
    entid = Column(VARCHAR(32), unique=True)
    DOM = Column(VARCHAR(255))
    REGCAP = Column(VARCHAR(40))
    faren = Column(VARCHAR(255))
    ESDATE = Column(VARCHAR(60))
    logo = Column(VARCHAR(255))
    ENTNAME = Column(VARCHAR(255))
    is_del = Column(TINYINT(4))
    create_ts = Column(Integer)
    update_ts = Column(Integer)

    def __init__(self, *arg, **kw):
        self.DOM = kw.get("DOM", None)
        self.ENTNAME = kw.get("ENTNAME", None)
        self.ESDATE = kw.get("ESDATE", None)
        self.REGCAP = kw.get("REGCAP", None)
        self.create_ts = kw.get("create_ts", None)
        self.entid = kw.get("entid", None)
        self.faren = kw.get("faren", None)
        self.getByFromId = kw.get("getByFromId", None)
        self.getByFromIdAndMod = kw.get("getByFromIdAndMod", None)
        self.id = kw.get("id", None)
        self.is_del = kw.get("is_del", None)
        self.logo = kw.get("logo", None)
        self.metadata = kw.get("metadata", None)
        self.update_ts = kw.get("update_ts", None)


class ComInfo2(Base, BaseModel):
    __tablename__ = 'com_info2'

    id = Column(Integer, primary_key=True)
    entid = Column(VARCHAR(32), unique=True)
    DOM = Column(VARCHAR(255))
    REGCAP = Column(VARCHAR(40))
    faren = Column(VARCHAR(255))
    ESDATE = Column(VARCHAR(60))
    logo = Column(VARCHAR(255))
    ENTNAME = Column(VARCHAR(255))
    is_del = Column(TINYINT(4))
    create_ts = Column(Integer)
    update_ts = Column(Integer)


class ComList(Base, BaseModel):
    __tablename__ = 'com_list'

    id = Column(Integer, primary_key=True)
    com_name = Column(VARCHAR(255))
    entid = Column(VARCHAR(40))
    is_del = Column(TINYINT(4))
    create_ts = Column(Integer)
    update_ts = Column(Integer)


if __name__ == '__main__':
    createInitFunction(ComList)



# -*- coding:utf-8 -*-
import json

import XX.File.FileHelper as cf


class UrlInfoHelper(object):

    # json str 2 redis。把异常的url记录下来,并把缓存删了
    @staticmethod
    def add2redis(url_info, redis_key, redis_conn, del_cache=0, spider="", get_url_cache_path=None, unique_url=None):
        try:
            redis_conn.rpush(redis_key, json.dumps(url_info))
        except:
            print("==UrlInfoHelper->Add redis is wrong")
        if del_cache:
            cache_fp = get_url_cache_path(unique_url(url_info.get("url")), spider=spider)
            if cf.FileHelper.is_file_exit(cache_fp):
                print("Remove cache file + " + cache_fp + "\t url  is " + url_info.get("url"))
                cf.FileHelper.remove_file(cache_fp)
            else:
                print("=====Cache is not exists========" + cache_fp)
        else:
            print("--" * 50, flush=True)


if __name__ == '__main__':
    pass
